==> dojo-1.10.6.tgz: package/cldr/nls/hr/chinese.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "ova subota",
	"field-sat-relative+1": "sljedeća subota",
	"field-dayperiod": "Prijepodne/popodne",
	"field-sun-relative+-1": "prošla nedjelja",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"field-minute": "Minuta",
	"field-day-relative+-1": "jučer",
	"field-weekday": "Dan u tjednu",
	"field-day-relative+-2": "prekjučer",
	"field-era": "Era",
	"field-hour": "Sat",
	"field-sun-relative+0": "ova nedjelja",
	"field-sun-relative+1": "sljedeća nedjelja",
	"field-wed-relative+-1": "prošla srijeda",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"field-day-relative+2": "prekosutra",
	"dateFormat-long": "d.M.y.",
	"field-tue-relative+0": "ovaj utorak",
	"field-zone": "Vremenska zona",
	"field-tue-relative+1": "sljedeći utorak",
	"field-week-relative+-1": "prošli tjedan",
	"dateFormat-medium": "d.M.y.",
	"field-year-relative+0": "ove godine",
	"field-year-relative+1": "sljedeće godine",
	"field-sat-relative+-1": "prošla subota",
	"field-year-relative+-1": "prošle godine",
	"field-year": "Godina",
	"field-fri-relative+0": "ovaj petak",
	"field-fri-relative+1": "sljedeći petak",
	"field-week": "Tjedan",
	"field-week-relative+0": "ovaj tjedan",
	"field-week-relative+1": "sljedeći tjedan",
	"field-month-relative+0": "ovaj mjesec",
	"field-month": "Mjesec",
	"field-month-relative+1": "sljedeći mjesec",
	"field-fri-relative+-1": "prošli petak",
	"field-second": "Sekunda",
	"field-tue-relative+-1": "prošli utorak",
	"field-day": "Dan",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"field-thu-relative+0": "ovaj četvrtak",
	"field-second-relative+0": "sada",
	"dateFormat-short": "d.M.y.",
	"field-thu-relative+1": "sljedeći četvrtak",
	"dateFormat-full": "E, d.M.y.",
	"field-wed-relative+0": "ova srijeda",
	"field-wed-relative+1": "sljedeća srijeda",
	"field-month-relative+-1": "prošli mjesec",
	"field-thu-relative+-1": "prošli četvrtak"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/hr/chinese.js <==
define(
//begin v1.x content
{
	"field-sat-relative+0": "ova subota",
	"field-sat-relative+1": "sljedeća subota",
	"field-dayperiod": "AM/PM",
	"field-sun-relative+-1": "prošla nedjelja",
	"field-mon-relative+-1": "prošli ponedjeljak",
	"field-minute": "Minuta",
	"field-day-relative+-1": "jučer",
	"field-weekday": "Dan u tjednu",
	"field-day-relative+-2": "prekjučer",
	"field-era": "Era",
	"field-hour": "Sat",
	"field-sun-relative+0": "ova nedjelja",
	"field-sun-relative+1": "sljedeća nedjelja",
	"field-wed-relative+-1": "prošla srijeda",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"field-day-relative+2": "prekosutra",
	"dateFormat-long": "d.M.y.",
	"field-tue-relative+0": "ovaj utorak",
	"field-zone": "Vremenska zona",
	"field-tue-relative+1": "sljedeći utorak",
	"field-week-relative+-1": "prošli tjedan",
	"dateFormat-medium": "d.M.y.",
	"field-year-relative+0": "ove godine",
	"field-year-relative+1": "sljedeće godine",
	"field-sat-relative+-1": "prošla subota",
	"field-year-relative+-1": "prošle godine",
	"field-year": "Godina",
	"field-fri-relative+0": "ovaj petak",
	"field-fri-relative+1": "sljedeći petak",
	"field-week": "Tjedan",
	"field-week-relative+0": "ovaj tjedan",
	"field-week-relative+1": "sljedeći tjedan",
	"field-month-relative+0": "ovaj mjesec",
	"field-month": "Mjesec",
	"field-month-relative+1": "sljedeći mjesec",
	"field-fri-relative+-1": "prošli petak",
	"field-second": "Sekunda",
	"field-tue-relative+-1": "prošli utorak",
	"field-day": "Dan",
	"field-mon-relative+0": "ovaj ponedjeljak",
	"field-mon-relative+1": "sljedeći ponedjeljak",
	"field-thu-relative+0": "ovaj četvrtak",
	"field-second-relative+0": "sada",
	"dateFormat-short": "d.M.y.",
	"field-thu-relative+1": "sljedeći četvrtak",
	"dateFormat-full": "E, d.M.y.",
	"field-wed-relative+0": "ova srijeda",
	"field-wed-relative+1": "sljedeća srijeda",
	"field-month-relative+-1": "prošli mjesec",
	"field-thu-relative+-1": "prošli četvrtak"
}
//end v1.x content
);
